@@ -83,6 +83,10 @@ class BindableUi(Generic[TWidget]):
         cast(ui.element, self.element).tailwind(*args)
         return self
 
+    def tooltip(self, text: str) -> Self:
+        cast(ui.element, self.element).tooltip(text)
+        return self
+
     def add_slot(self, name: str, template: Optional[str] = None):
         """Add a slot to the element.
 
@@ -138,6 +142,9 @@ class BindableUi(Generic[TWidget]):
 
         return self
 
+    def clear(self) -> None:
+        cast(ui.element, self.element).clear()
+
 
 class SingleValueBindableUi(BindableUi[TWidget], Generic[T, TWidget]):
     def __init__(self, value: TMaybeRef[T], element: TWidget) -> None:
@@ -350,7 +357,7 @@ class SwitchBindableUi(SingleValueBindableUi[bool, ui.switch]):
         def _():
             ele.value = binder.value
 
-        ele.on("update:modelValue", onValueChanged, [None], throttle=0)
+        ele.on("update:modelValue", onValueChanged, [None], throttle=0)  # type: ignore
 
     def __init__(
         self,
@@ -436,6 +443,58 @@ class CheckboxBindableUi(SingleValueBindableUi[bool, ui.checkbox]):
         return self
 
 
+class DateBindableUi(SingleValueBindableUi[Optional[str], ui.date]):
+    def __init__(
+        self,
+        value: TMaybeRef[Optional[str]] = None,
+        *,
+        mask: TMaybeRef[str] = "YYYY-MM-DD",
+        on_change: Optional[Callable[..., Any]] = None,
+    ) -> None:
+        kws = {
+            "value": value,
+            "mask": mask,
+            "on_change": on_change,
+        }
+
+        value_kws = _convert_kws_ref2value(kws)
+
+        element = ui.date(**value_kws)
+
+        super().__init__(value, element)
+
+        for key, value in kws.items():
+            if is_ref(value) and key != "value":
+                self.bind_prop(key, value)  # type: ignore
+
+        self._ex_setup()
+
+    def _ex_setup(self):
+        ele = self.element
+
+        @effect
+        def _():
+            ele.value = self.value
+
+        def onModelValueChanged(e):
+            self._ref.value = e.args[0] or ""  # type: ignore
+
+        ele.on("update:modelValue", handler=onModelValueChanged)
+
+    def bind_prop(self, prop: str, ref_ui: ReadonlyRef):
+        if prop == "value":
+            return self.bind_value(ref_ui)
+
+        return super().bind_prop(prop, ref_ui)
+
+    def bind_value(self, ref_ui: ReadonlyRef[bool]):
+        @effect
+        def _():
+            self.element.on_value_change(ref_ui.value)
+
+        return self
+
+
 class InputBindableUi(SingleValueBindableUi[str, ui.input]):
     def __init__(
         self,
